Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(401)

Unified Diff: third_party/WebKit/Source/platform/scheduler/base/work_queue.h

Issue 2786083005: scheduler: Maintain a constant enqueue order for every task (Closed)
Patch Set: WASM workaround no longer needed Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/scheduler/base/work_queue.h
diff --git a/third_party/WebKit/Source/platform/scheduler/base/work_queue.h b/third_party/WebKit/Source/platform/scheduler/base/work_queue.h
index 1dd47e12f6f6856158e43f6c698efe1622c39a49..5d139d0cbae92f320cf8c7bbabc152fcd7a00f62 100644
--- a/third_party/WebKit/Source/platform/scheduler/base/work_queue.h
+++ b/third_party/WebKit/Source/platform/scheduler/base/work_queue.h
@@ -98,11 +98,11 @@ class BLINK_PLATFORM_EXPORT WorkQueue {
bool ShouldRunBefore(const WorkQueue* other_queue) const;
// Submit a fence. When TakeTaskFromWorkQueue encounters a task whose
// enqueue_order is >= |fence| then the WorkQueue will start pretending to be.
// empty.
// Inserting a fence may supersede a previous one and unblock some tasks.
// Returns true if any tasks where unblocked, returns false otherwise.
- bool InsertFence(EnqueueOrder fence);
+ bool InsertFence(SequenceNumber fence);
// Removes any fences that where added and if WorkQueue was pretending to be
// empty, then the real value is reported to WorkQueueSets. Returns true if
@@ -121,7 +121,7 @@ class BLINK_PLATFORM_EXPORT WorkQueue {
size_t work_queue_set_index_;
HeapHandle heap_handle_;
const char* const name_;
- EnqueueOrder fence_;
+ SequenceNumber fence_;
const QueueType queue_type_;
DISALLOW_COPY_AND_ASSIGN(WorkQueue);
@@ -98,11 +98,11 @@ class BLINK_PLATFORM_EXPORT WorkQueue {
bool ShouldRunBefore(const WorkQueue* other_queue) const;
// Submit a fence. When TakeTaskFromWorkQueue encounters a task whose
- // enqueue_order is >= |fence| then the WorkQueue will start pretending to be.
- // empty.
+ // sequence number is >= |fence| then the WorkQueue will start pretending to
+ // be. empty.
// Inserting a fence may supersede a previous one and unblock some tasks.
// Returns true if any tasks where unblocked, returns false otherwise.

Powered by Google App Engine
This is Rietveld 408576698